@@ -23,8 +23,10 @@ class RequestHandler(tornado.web.RequestHandler):
         try:
             self.finish(app.db.Get(key))
             app.get += 1
+            print "get", key
         except KeyError:
             app.miss += 1
+            print "miss", key
             raise tornado.web.HTTPError(404)
 
     def put(self, key):
@@ -33,6 +35,7 @@ class RequestHandler(tornado.web.RequestHandler):
             app = self.application
             app.db.Put(key, value)
             app.put += 1
+            print "put", key
 
     def write_error(self, status_code, **kwargs):
         self.finish()
